@@ -1,5 +1,6 @@
-#!/bin/sh
-# Copyright (C) 2014-2016 Red Hat, Inc. All rights reserved.
+#!/usr/bin/env bash
+
+# Copyright (C) 2017 Red Hat, Inc. All rights reserved.
 #
 # This copyrighted material is made available to anyone wishing to use,
 # modify, copy, or redistribute it subject to the terms and conditions
@@ -11,7 +12,7 @@
 
 # Exercise cache flushing is abortable
 
-SKIP_WITH_LVMLOCKD=1
+
 SKIP_WITH_LVMPOLLD=1
 
 . lib/inittest
@@ -37,19 +38,35 @@ done
 
 
 # Delay dev to ensure we have some time to 'capture' interrupt in flush
-aux delay_dev "$dev1" 0 500 $(get first_extent_sector "$dev1"):
+aux delay_dev "$dev1" 100 0 "$(get first_extent_sector "$dev1"):"
+
+# TODO, how to make writeback cache dirty
+test "$(get lv_field $vg/$lv1 cache_dirty_blocks)" -gt 0 || {
+	lvdisplay --maps $vg
+	skip "Cannot make a dirty writeback cache LV."
+}
 
-lvdisplay --maps $vg
 sync
 dd if=/dev/zero of="$DM_DEV_DIR/$vg/$lv1" bs=4k count=100 conv=fdatasync
 
-LVM_TEST_TAG="kill_me_$PREFIX" lvconvert -v --splitcache $vg/$lv1 >log 2>&1 &
+LVM_TEST_TAG="kill_me_$PREFIX" lvconvert -v --splitcache $vg/$lv1 >logconvert 2>&1 &
 PID_CONVERT=$!
-sleep 0.2
+for i in {1..50}; do
+	dmsetup table "$vg-$lv1" | grep cleaner && break
+	test "$i" -ge 100 && die "Waited for cleaner policy on $vg/$lv1 too long!"
+	echo "Waiting for cleaner policy on $vg/$lv1"
+	sleep .05
+done
 kill -INT $PID_CONVERT
 aux enable_dev "$dev1"
 wait
-egrep "Flushing.*aborted" log
+
+grep -E "Flushing.*aborted" logconvert || {
+	cat logconvert || true
+	vgremove -f $vg
+	die "Flushing of $vg/$lv1 not aborted ?"
+}
+
 # check the table got restored
 check grep_dmsetup table $vg-$lv1 "writeback"
 
