@@ -10,7 +10,7 @@
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA2110-1301 USA
 
-SKIP_WITH_LVMLOCKD=1
+
 SKIP_WITH_LVMPOLLD=1
 
 . lib/inittest
@@ -32,12 +32,12 @@ aux prepare_pvs 16 32
 
 get_devs
 
-vgcreate -s 1M "$vg" "${DEVICES[@]}"
+vgcreate $SHARED -s 1M "$vg" "${DEVICES[@]}"
 
 trap 'cleanup_mounted_and_teardown' EXIT
 
 # Create 13-way striped raid5 (14 legs total)
-lvcreate --yes --type raid5_ls --stripesize 64K --stripes 10 -L200M -n$lv1 $vg
+lvcreate --yes --type raid5_ls --stripesize 64K --stripes 10 -L4 -n$lv1 $vg
 check lv_first_seg_field $vg/$lv1 segtype "raid5_ls"
 check lv_first_seg_field $vg/$lv1 stripesize "64.00k"
 check lv_first_seg_field $vg/$lv1 data_stripes 10
@@ -49,10 +49,13 @@ mount "$DM_DEV_DIR/$vg/$lv1" $mount_dir
 mkdir -p $mount_dir/1 $mount_dir/2
 
 echo 3 >/proc/sys/vm/drop_caches
+# FIXME: This is filling up ram disk. Use sane amount of data please! Rate limit the data written!
 cp -r /usr/bin $mount_dir/1 >/dev/null 2>/dev/null &
 cp -r /usr/bin $mount_dir/2 >/dev/null 2>/dev/null &
+# FIXME: should this wait for above two processes and sync then?
 sync &
 
+# FIXME: wait_for_sync - is this really testing anything under load?
 aux wait_for_sync $vg $lv1
 aux delay_dev "$dev2" 0 200
 
