@@ -397,7 +397,8 @@ static struct logical_volume *_set_up_pvmove_lv(struct cmd_context *cmd,
 			/* Presence of exclusive LV decides whether pvmove must be also exclusive */
 			if (!seg_only_exclusive(seg)) {
 				holder = lv_lock_holder(lv);
-				if (seg_only_exclusive(first_seg(holder)) || lv_is_origin(holder) || lv_is_cow(holder))
+				if (seg_only_exclusive(first_seg(holder)) || lv_is_origin(holder) ||
+				    lv_is_cow(holder) || lv_is_active_exclusive(holder))
 					needs_exclusive = 1;
 			} else
 				needs_exclusive = 1;
@@ -674,7 +675,8 @@ static int _pvmove_setup_single(struct cmd_context *cmd,
 		dm_list_iterate_items(lvl, lvs_changed) {
 			lvh = lv_lock_holder(lvl->lv);
 			/* Exclusive LV decides whether pvmove must be also exclusive */
-			if (lv_is_origin(lvh) || seg_only_exclusive(first_seg(lvh)))
+			if (lv_is_origin(lvh) || seg_only_exclusive(first_seg(lvh)) ||
+			    lv_is_active_exclusive(lvh))
 				exclusive = 1;
 		}
 
